﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace FileConverterPro {
    public partial class UserForm : Form {

        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Browsable(false)]
        public string UserName { get { return txtUserName.Text; } set { txtUserName.Text = value; } }

        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Browsable(false)]
        public string Password { get { return txtPassword.Text; } set { txtPassword.Text = value; } }

        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Browsable(false)]
        public WCFUserRights Rights { get; set; }

        private bool HasRights(WCFUserRights r) {
            return ((WCFUserRights)Rights & r) == r;
        }


        public UserForm() {
            InitializeComponent();
            UserName = Password = "";
            Rights = WCFUserRights.None;
        }

        private const string DummyPassword = "$#dummypwd#$";

        public bool PasswordChanged { get { return txtPassword.Text != DummyPassword; } }

        protected override void OnLoad(EventArgs e) {
            base.OnLoad(e);

            if (UserName.ToLower() == "admin") {
                // the admin user cannot be changed via web service.
                txtUserName.Enabled = false;
                txtPassword.Enabled = false;
                groupBox1.Enabled = false;
                btnOK.Enabled = false;
            }

            if (!string.IsNullOrEmpty(UserName)) {
                txtUserName.Enabled = false;
                txtPassword.Text = DummyPassword;
            }

            txtUserName.Text = UserName;
            

            chkConnect.Checked = HasRights(WCFUserRights.Connect);
            chkListOfOwnJobs.Checked = HasRights(WCFUserRights.GetListOfOwnJobs);
            chkListOfAllJobs.Checked = HasRights(WCFUserRights.GetListOfAllJobs);
            chkStartStop.Checked = HasRights(WCFUserRights.AllowStartStop);
            chkAllowManageUsers.Checked = HasRights(WCFUserRights.AllowManageUsers);
            chkManageOCRprofiles.Checked = HasRights(WCFUserRights.AllowManagerProfiles);
            chkAllowManageJobs.Checked = HasRights(WCFUserRights.AllowManageJobs);

        }

        private void btnOK_Click(object sender, EventArgs e) {
            string userName = txtUserName.Text.Trim();
            string password = txtPassword.Text.Trim();

            if (string.IsNullOrEmpty(userName)) {
                MessageBox.Show("Please type in a user name");
                return;
            }
            if (string.IsNullOrEmpty(password)) {
                MessageBox.Show("Please type in a password");
                return;
            }


            UserName = userName;
            Password = password;

            WCFUserRights r = WCFUserRights.None;
            if (chkConnect.Checked)
                r |= WCFUserRights.Connect;
            if (chkListOfOwnJobs.Checked)
                r |= WCFUserRights.GetListOfOwnJobs;
            if (chkListOfAllJobs.Checked)
                r |= WCFUserRights.GetListOfAllJobs;
            if (chkStartStop.Checked)
                r |= WCFUserRights.AllowStartStop;
            if (chkAllowManageUsers.Checked)
                r |= WCFUserRights.AllowManageUsers;
            if (chkManageOCRprofiles.Checked)
                r |= WCFUserRights.AllowManagerProfiles;
            if (chkAllowManageJobs.Checked)
                r |= WCFUserRights.AllowManageJobs;

            Rights = r;
            DialogResult = DialogResult.OK;
        }
    }
}
